'use strict';
/**
  * 日历组件
  * opt: 组件配置  type: obj
  * data-align: left; 对齐方式，默认左对齐
  */
function multiCalendar(opt){
    this.ele = ws_$('multiCalendar')[0];
    this.opt = opt || {};       //组件配置
    this.opt.width = 330;       //组件宽度
    this.opt.height = 240;      //组件高度
    var align = this.ele.getAttribute("data-align");    //获取对齐配置
    this.opt.align = align == "right" ? align : "left"; // 默认左对齐
    this.init();
    this.wrap;
}

multiCalendar.prototype = {
    arr_pin: [31,28,31,30,31,30,31,31,30,31,30,31],     //平年每月天数数组
    arr_run: [31,29,31,30,31,30,31,31,30,31,30,31],     //闰年每月天数数组
    /*currentYear: new Date().getFullYear(),    //当前显示的年份标记
    c_year: new Date().getFullYear(),
    currentMonth: new Date().getMonth(),      //当前显示的月份标记
    c_month: new Date().getMonth(),
    currentWeek: new Date().getDay(),         //当前显示的星期标记
    weekArr : ["星期日","星期一","星期二","星期三","星期四","星期五","星期六"],*/
    monthArr : ["一月","二月","三月","四月","五月","六月","七月","八月","九月","十月","十一月","十二月"],
    initData: function(){
        this.currentYear = new Date().getFullYear();    //当前显示的年份标记
        this.c_year = new Date().getFullYear();
        this.currentMonth = new Date().getMonth();      //当前显示的月份标记
        this.c_month = new Date().getMonth();
    },

    /**
     * [初始化组件]
     * @return {[type]} [description]
     */
    init: function(){
        this.initData();
        var _that = this;
        if(!this.ele.style.width){
            this.ele.style.width = '200px';
        }
        if(!this.ele.style.height){
            this.ele.style.height = '30px';
        }
        this.ele.style.boxSizing = 'border-box';

        this.ele.onfocus = function(){
            if(_that.wrap){
                _that.showWrap();
            }else{
                _that.renderWrap();
            }
        }

    },
    /**
     * [绑定事件]
     * @return {[type]} [description]
     */
    bindEvent: function(){
        var _that = this;
        this.ele.onclick = function(e){
            stopPropagation(e);
        }
        this.wrap.onclick = function(e){
            stopPropagation(e);
        }

        document.body.onclick = function(e){
            _that.hideWrap();
        }

        this.recentOneDay();
        this.recentSevenDay();
        this.recentThirtyDay();
        this.naturalDay();
        this.naturalWeek();
        this.naturalMonth();
    },
    /**
     * [渲染组件框架]
     * @return {[type]} [description]
     */
    renderWrap: function(){
        var pos = this.getPosition();
        var dom = document.createElement("div");
        dom.className = 'multiCalendar-wrap';
        dom.style.width = this.opt.width + 'px';
        dom.style.height = this.opt.height + 'px';
        dom.style.position = 'absolute';
        dom.style.left = pos.x + 'px';
        dom.style.top = pos.y + 'px';
        document.body.appendChild(dom);
        // 左侧tab
        var leftPanel = document.createElement('div');
        leftPanel.className = 'mc-leftPanel';
        var listHtml = '<ul><li id="ws-one" class="ws-active">最近1天</li><li id="ws-seven">最近7天</li><li id="ws-thirty">最近30天</li><li id="ws-naturalday">自然日</li><li id="ws-naturalweek">自然周</li><li id="ws-naturalmonth">自然月</li></ul>';
        leftPanel.innerHTML = listHtml;
        dom.appendChild(leftPanel);
        // 右侧展示区域
        this.rightPanel = document.createElement('div');
        this.rightPanel.className = 'mc-rightPanel';
        dom.appendChild(this.rightPanel);

        this.wrap = dom;    // 缓存dom
        this.bindEvent();   // 绑定事件

        var _that = this;
        var day = new Date().Format("YYYY-MM-DD");
        var result = '<div class="ws-inline-day ws-inline-oneday" id="ws-inline-oneday">'+day+'<div>'
        _that.rightPanel.innerHTML = result;
        var btn = document.getElementById('ws-inline-oneday');
        btn.onclick = function(){
            _that.setValue(day, day);
            _that.hideWrap();
        }
    },
    /**
     * [recentOneDay: 最近一天]
     * @return {[type]} [description]
     */
    recentOneDay: function(){
        var _that = this;
        var recentOneDayBtn = document.getElementById('ws-one');
        recentOneDayBtn.onclick = function(e){
            ws_$('ws-active')[0].className = '';
            recentOneDayBtn.className = 'ws-active';
            var day = new Date().Format("YYYY-MM-DD");
            var result = '<div class="ws-inline-day ws-inline-oneday" id="ws-inline-oneday">'+day+'<div>'
            _that.rightPanel.innerHTML = result;
            var btn = document.getElementById('ws-inline-oneday');
            btn.onclick = function(){
                _that.setValue(day, day);
                _that.hideWrap();
            }
        }
    },
    /**
     * [recentSevenDay: 最近七天]
     * @return {[type]} [description]
     */
    recentSevenDay: function(){
        var _that = this;
        var recentSevenDayBtn = document.getElementById('ws-seven');
        recentSevenDayBtn.onclick = function(e){
            ws_$('ws-active')[0].className = '';
            recentSevenDayBtn.className = 'ws-active';
            var day = new Date().Format("YYYY-MM-DD");

            var last = _that.getSpaceDay(-6);

            var result = '<div class="ws-inline-day ws-inline-sevenday" id="ws-inline-sevenday">('+last + ')~(' + day+')<div>'
            _that.rightPanel.innerHTML = result;
            var btn = document.getElementById('ws-inline-sevenday');

            btn.onclick = function(){
                _that.setValue(last, day);
                _that.hideWrap();
            }
        }
    },
    /**
     * [recentThirtyDay: 最近三十天]
     * @return {[type]} [description]
     */
    recentThirtyDay: function(){
        var _that = this;
        var recentThirtyDayBtn = document.getElementById('ws-thirty');
        recentThirtyDayBtn.onclick = function(e){
            ws_$('ws-active')[0].className = '';
            recentThirtyDayBtn.className = 'ws-active';
            var day = new Date().Format("YYYY-MM-DD");

            var last = _that.getSpaceDay(-29);

            var result = '<div class="ws-inline-day ws-inline-thirtyday" id="ws-inline-thirtyday">('+last + ')~(' + day+')<div>'
            _that.rightPanel.innerHTML = result;
            var btn = document.getElementById('ws-inline-thirtyday');
            btn.onclick = function(){
                _that.setValue(last, day);
                _that.hideWrap();
            }
        }
    },
    /**
     * [自然日]
     * @return {[type]} [description]
     */
    naturalDay: function(){
        var _that = this;
        var naturalDayBtn = document.getElementById('ws-naturalday');

        naturalDayBtn.onclick = function(e){
            _that.initData();

            ws_$('ws-active')[0].className = '';
            naturalDayBtn.className = 'ws-active';

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-day-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillDate(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;

            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.dayNext();
            }
            _that.dayPrev();

        }
    },
    /**
     * [生成日历]
     * @param  {[type]} year  [description]
     * @param  {[type]} month [description]
     * @return {[type]}       [description]
     */
    fillDate: function(year, month){
        var html = "";
        var today = new Date().getDate();  //获取今天是几号

        var firstDay = new Date(year, month,1).getDay();  //获取本月第一天是星期几

        firstDay = firstDay==0 ? 6 : firstDay-1;   //表头空几格

        var lastDay = new Date(year,month+1,0).getDay(); //获取本月最后一天是星期几

        var totalDay = new Date(year,month+1,0).getDate(); //获取本月最后一天是几号

        var lastTotalDay = new Date(year,month,0).getDate(); //获取上月最后一天是几号

        var dayLeft = 42 - firstDay - totalDay;  //表尾留几格

        for( var i = firstDay; i>0; i--){
            html += '<span class="ws-day ws-day-gray" data-date="'+year+'-'+(month+1)+'-'+ (lastTotalDay-i+1) +'">' + (lastTotalDay-i+1) +'</span>';
        }

        for( var i = 1; i<=totalDay; i++){
            if( year >= this.c_year && month >= this.c_month){   //
                if(i <= today){
                    if(year==this.c_year && this.c_month==month && i==today){
                        html += '<span class="ws-day ws-day-normal current" data-date="'+year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i) +'" onclick="setVal(this)">' + i + '</span>';
                    }else{
                        html += '<span class="ws-day ws-day-normal" data-date="'+year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i) +'" onclick="setVal(this)">' + i + '</span>';
                    }
                }else{
                    html += '<span class="ws-day ws-day-gray" data-date="'+year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i) +'">' + i + '</span>';
                }
            }else{
                html += '<span class="ws-day ws-day-normal" data-date="'+year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i) +'" onclick="setVal(this)">' + i + '</span>';
            }
        }

        for( var i=1; i<=dayLeft; i++){
            html += '<span class="ws-day ws-day-gray" data-date="'+year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i) +'">' + i + '</span>';
        }

        return html;
    },
    dayNext:function(){
        var oNext = document.getElementById("ws-day-next");
        var _that = this;
        oNext.onclick = function(){
            _that.currentMonth ++;
            if(_that.currentMonth>11){
                _that.currentMonth = 0;
                _that.currentYear++;
            }
            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-day-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillDate(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;
            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.dayNext();
            }
            _that.dayPrev();
        }
    },
    dayPrev:function(){
        var oNext = document.getElementById("ws-day-prev");
        var _that = this;
        oNext.onclick = function(){
            _that.currentMonth --
            if(_that.currentMonth < 0){
                _that.currentMonth = 11;
                _that.currentYear--;
            }

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-day-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-day-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillDate(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;
            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.dayNext();
            }
            _that.dayPrev();
        }
    },
    /**
     * [自然周]
     * @return {[type]} [description]
     */
    naturalWeek: function(){
        var _that = this;
        var naturalWeekBtn = document.getElementById('ws-naturalweek');

        naturalWeekBtn.onclick = function(e){
            _that.initData();

            ws_$('ws-active')[0].className = '';
            naturalWeekBtn.className = 'ws-active';

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-week-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillWeek(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;

            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.weekNext();
            }
            _that.weekPrev();

        }
    },
    weekNext:function(){
        var oNext = document.getElementById("ws-week-next");
        var _that = this;
        oNext.onclick = function(){
            _that.currentMonth ++;
            if(_that.currentMonth>11){
                _that.currentMonth = 0;
                _that.currentYear++;
            }
            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-week-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillWeek(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;
            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.weekNext();
            }
            _that.weekPrev();
        }
    },
    weekPrev:function(){
        var oNext = document.getElementById("ws-week-prev");
        var _that = this;
        oNext.onclick = function(){
            _that.currentMonth --
            if(_that.currentMonth < 0){
                _that.currentMonth = 11;
                _that.currentYear--;
            }

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-week-prev">&lt;</th><th colspan=3>'+_that.currentYear+'年</th><th colspan=2>'+(_that.currentMonth + 1)+'月</th><th id="ws-week-next">&gt;</th></tr>';
            }
            html += '<tr class="ws-name"><td>一</td><td>二</td><td>三</td><td>四</td><td>五</td><td>六</td><td>日</td></tr>';
                html += '</table>';

            html += _that.fillWeek(_that.currentYear, _that.currentMonth)

            _that.rightPanel.innerHTML = html;
            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.weekNext();
            }
            _that.weekPrev();
        }
    },
    /**
     * [生成日历]
     * @param  {[type]} year  [description]
     * @param  {[type]} month [description]
     * @return {[type]}       [description]
     */
    fillWeek: function(year, month){
        var html = '<div class="ws-week" onclick="setWeek(this)">';
        var today = new Date().getDate();  //获取今天是几号

        var firstDay = new Date(year, month,1).getDay();  //获取本月第一天是星期几

        firstDay = firstDay==0 ? 6 : firstDay-1;   //表头空几格

        var lastDay = new Date(year,month+1,0).getDay(); //获取本月最后一天是星期几

        var totalDay = new Date(year,month+1,0).getDate(); //获取本月最后一天是几号

        var lastTotalDay = new Date(year,month,0).getDate(); //获取上月最后一天是几号

        var dayLeft = 42 - firstDay - totalDay;  //表尾留几格



        for( var i = firstDay; i>0; i--){
            var dateStr = year+'-'+ month +'-'+ (lastTotalDay-i+1);
            html += '<span class="ws-day ws-day-gray" data-date="'+dateStr +'">' + (lastTotalDay-i+1) +'</span>';
            if(new Date(dateStr).getDay() == 0){
                html += '</div><div class="ws-week" onclick="setWeek(this)">';
            }
        }

        for( var i = 1; i<=totalDay; i++){
            var dateStr = year+'-'+(month+1)+'-'+ (i < 10 ? '0' + i : i);
            if( year >= this.c_year && month >= this.c_month){
                if(i <= today){
                    if(year==this.c_year && this.c_month==month && i==today){
                        html += '<span class="ws-day ws-day-normal current" data-date="'+dateStr +'">' + i + '</span>';
                    }else{
                        html += '<span class="ws-day ws-day-normal" data-date="'+ dateStr +'">' + i + '</span>';
                    }
                    if(new Date(dateStr).getDay() == 0){
                        html += '</div><div class="ws-week" onclick="setWeek(this)">';
                    }
                }else{
                    html += '<span class="ws-day ws-day-gray ws-day-none" data-forbidden="1" data-date="'+ dateStr +'">' + i + '</span>';
                    if(new Date(dateStr).getDay() == 0){
                        html += '</div><div class="">';
                    }
                }
            }else{
                html += '<span class="ws-day ws-day-normal" data-date="'+ dateStr +'">' + i + '</span>';
                if(new Date(dateStr).getDay() == 0){
                    html += '</div><div class="ws-week" onclick="setWeek(this)">';
                }
            }

            
        }

        for( var i=1; i<=dayLeft; i++){
            var dateStr = year+'-'+(month+2)+'-'+ (i < 10 ? '0' + i : i);
            html += '<span class="ws-day ws-day-gray" data-date="'+ dateStr +'">' + i + '</span>';
            if(new Date(dateStr).getDay() == 0){
                html += '</div><div class="ws-week" onclick="setWeek(this)">';
            }
        }

        html += '</div>';

        return html;
    },
    /**
     * [自然月]
     * @return {[type]} [description]
     */
    naturalMonth: function(){
        var _that = this;
        var naturalWeekBtn = document.getElementById('ws-naturalmonth');

        naturalWeekBtn.onclick = function(e){
            _that.initData();

            ws_$('ws-active')[0].className = '';
            naturalWeekBtn.className = 'ws-active';

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5><font id="ws-na-month">'+_that.currentYear+'</font>年</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5>'+_that.currentYear+'年</th><th id="ws-month-next">&gt;</th></tr>';
            }
            html += '</table><div class="ws-month-wrap">';

            for(var i = 0; i<12; i++){
                html += '<span data-month="'+ (i+1) +'"  data-year="'+_that.currentYear+'" onclick="setMonth(this);">' + _that.monthArr[i] + '</span>';
            }

            html += '</div>';

            _that.rightPanel.innerHTML = html;

            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.monthNext();
            }
            _that.monthPrev();

        }
    },
    monthNext:function(){
        var oNext = document.getElementById("ws-month-next");
        var _that = this;
        oNext.onclick = function(){

            _that.currentYear++;
 

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year){
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5><font id="ws-na-month">'+_that.currentYear+'</font>年</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5>'+_that.currentYear+'年</th><th id="ws-month-next">&gt;</th></tr>';
            }
            html += '</table><div class="ws-month-wrap">';

            for(var i = 0; i<12; i++){
                html += '<span data-month="'+ (i+1) +'" data-year="'+_that.currentYear+'" onclick="setMonth(this);">' + _that.monthArr[i] + '</span>';
            }

            html += '</div>';

            _that.rightPanel.innerHTML = html;

            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.monthNext();
            }
            _that.monthPrev();
        }
    },
    monthPrev:function(){
        var oNext = document.getElementById("ws-month-prev");
        var _that = this;
        oNext.onclick = function(){
            _that.currentYear--;
            

            var html = '<table class="ws-table" cellpadding="0" cellspacing="0">';
            if( _that.currentYear == _that.c_year && _that.currentMonth == _that.c_month ){
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5><font id="ws-na-month">'+_that.currentYear+'</font>年</th><th id=""></th></tr>';
            }else{
                html += '<tr><th id="ws-month-prev">&lt;</th><th colspan=5>'+_that.currentYear+'年</th><th id="ws-month-next">&gt;</th></tr>';
            }
            html += '</table><div class="ws-month-wrap">';

            for(var i = 0; i<12; i++){
                html += '<span data-month="'+ (i+1) +'" data-year="'+_that.currentYear+'" onclick="setMonth(this);">' + _that.monthArr[i] + '</span>';
            }

            html += '</div>';

            _that.rightPanel.innerHTML = html;
            
            if( _that.currentYear != _that.c_year || _that.currentMonth != _that.c_month ){
                _that.monthNext();
            }
            _that.monthPrev();
        }
    },

    // 显示组件
    showWrap: function(){
        this.wrap.style.display = 'block';
    },
    // 隐藏组件
    hideWrap: function(){
        this.wrap.style.display = 'none';
    },
    /**
     * [获取组件默认文字偏移量]
     * @return {[type]} [description]
     */
    getPosition: function(){
        var pos = {},
            eleW = +this.ele.style.width.replace('px', ''),  //输入框宽度
            eleH = +this.ele.style.height.replace('px', ''); //输入框高度
        if(this.opt.align == 'left'){   //左对齐
            pos.x = this.ele.offsetLeft;
            pos.y = Number(this.ele.offsetTop + eleH);
        }else{  //右对齐
            pos.x = Number(this.ele.offsetLeft + eleW - this.opt.width - 2);
            pos.y = Number(this.ele.offsetTop + eleH);
        }

        return pos;
    },
    /**
     * [设定输入框的值]
     */
    setValue: function(begin, end){
        if(begin == end){
            var date = begin;
        }else{
            var date = '（' + begin + '）~（' + end + '）';
        }
        var ele = ws_$('multiCalendar')[0];
        ws_$('multiCalendar-wrap')[0].style.display = 'none';
        this.ele.value = date;
        ele.setAttribute('data-begin', begin);
        ele.setAttribute('data-end', end);
    },
    /**
     * [getSpaceDay : 获取相隔长度的日期]
     * @param  {[type]} length [description]
     */
    getSpaceDay: function(length){
        var now = new Date().Format('YYYY-MM-DD');
        var nowStr = new Date(now).valueOf();
        var resStr = +nowStr + 24*60*60*1000*length;
        var result = new Date(resStr).Format('YYYY-MM-DD');
        return result;
    }    
}

function setVal(obj){
    var date = obj.getAttribute('data-date');
    var ele = ws_$('multiCalendar')[0];
    ws_$('multiCalendar-wrap')[0].style.display = 'none';
    ele.value = date;
    ele.setAttribute('data-begin', date);
    ele.setAttribute('data-end', date);
}

function setWeek(obj){
	var arr = [];
	for(var i = 0; i < obj.childNodes.length; i++){
		if(!obj.childNodes[i].getAttribute('data-forbidden')){
			arr.push(obj.childNodes[i]);
		}
	}
	var len = arr.length - 1;
    var begin = arr[0].getAttribute('data-date');
    var end = arr[len].getAttribute('data-date');
    var date = '（' + begin + '）~（' + end + '）';
    var ele = ws_$('multiCalendar')[0];
    ws_$('multiCalendar-wrap')[0].style.display = 'none';
    ele.value = date;
    ele.setAttribute('data-begin', begin);
    ele.setAttribute('data-end', end);
}
/**
 * [setMonth 设定自然月的值]
 * @param {[type]} obj [description]
 */
function setMonth(obj){
    var arr_pin = [31,28,31,30,31,30,31,31,30,31,30,31];     //平年每月天数数组
    var arr_run = [31,29,31,30,31,30,31,31,30,31,30,31];     //闰年每月天数数组
    var mon = obj.getAttribute('data-month');
    var year = obj.getAttribute('data-year');
    var startDay = 1, endDay = '';
    if(isRun(year)){
        endDay = arr_run[mon - 1];
    }else{
        endDay = arr_pin[mon - 1];
    }
    var begin = year + '-' + mon + '-' + startDay;
    var end = year + '-' + mon + '-' + endDay;
    var date = '（' + begin + '）~（' + end + '）';
    var ele = ws_$('multiCalendar')[0];
    ws_$('multiCalendar-wrap')[0].style.display = 'none';
    ele.value = date;
    ele.setAttribute('data-begin', begin);
    ele.setAttribute('data-end', end);
}

//初始化
new multiCalendar();

// 自定义选择class方法
function ws_$(classnames) {
    var classobj = new Array(); //定义数组
    var tags = document.getElementsByTagName("*"); //获取HTML的所有标签
    for (var i in tags) { //对标签进行遍历
        if (tags[i].nodeType == 1) { //判断节点类型
            if (tags[i].getAttribute("class") == classnames) //
            {
                classobj.push(tags[i]);
            }
        }
    }
    return classobj; //返回组成的数组
}
// 阻止冒泡
function stopPropagation(e) {
    e = e || window.event;
    if(e.stopPropagation) {     //W3C阻止冒泡方法
        e.stopPropagation();
    } else {
        e.cancelBubble = true; //IE阻止冒泡方法
    }
}

// 对Date的扩展，将 Date 转化为指定格式的String
// 月(M)、日(d)、小时(h)、分(m)、秒(s)、季度(q) 可以用 1-2 个占位符，
// 年(y)可以用 1-4 个占位符，毫秒(S)只能用 1 个占位符(是 1-3 位的数字)
// 例子：
// (new Date()).Format("yyyy-MM-dd hh:mm:ss.S") ==> 2006-07-02 08:09:04.423
// (new Date()).Format("yyyy-M-d h:m:s.S")      ==> 2006-7-2 8:9:4.18
Date.prototype.Format = function (fmt) { //author: meizz
    var o = {
        "M+": this.getMonth() + 1, //月份
        "D+": this.getDate(), //日
        "h+": this.getHours(), //小时
        "m+": this.getMinutes(), //分
        "s+": this.getSeconds(), //秒
        "q+": Math.floor((this.getMonth() + 3) / 3), //季度
        "S": this.getMilliseconds() //毫秒
    };
    if (/(Y+)/.test(fmt)) fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
    for (var k in o)
    if (new RegExp("(" + k + ")").test(fmt)) fmt = fmt.replace(RegExp.$1, (RegExp.$1.length == 1) ? (o[k]) : (("00" + o[k]).substr(("" + o[k]).length)));
    return fmt;
}

/**
 * [判断是否闰年]
 * @param  {[type]}  year [description]
 * @return {Boolean}      [description]
 */
function isRun(str){
    var year;
    year = Number(typeof(str) == 'undefined' ? new Date().getFullYear() : str);

    if( year%4==0 && year%100!=0 || year%400==0){
        return true;
    }else{
        return false;
    }
}